@@ -44,6 +44,3 @@ SlideId = os.getenv('SlideId', SlideId)
 
 RedisHost = os.getenv('RedisHost', '127.0.0.1')
 RedisPort = os.getenv('RedisPort', 6379)
-
-SlideCloudUrl = 'http://private.intemedic.com:6002'
-AuthUrl = 'http://private.intemedic.com:6001'
